@@ -1,8 +1,8 @@
 # -*- coding: utf-8 -*-
 from pathlib import Path
+from typing import List
 
 from fastflix.models.encode import AttachmentTrack
-from fastflix.shared import clean_file_string
 
 
 def image_type(file: Path | str) -> tuple[str | None, str | None]:
@@ -16,14 +16,19 @@ def image_type(file: Path | str) -> tuple[str | None, str | None]:
     return mime_type, ext_type
 
 
-def build_attachments(attachments: list[AttachmentTrack]) -> str:
+def build_attachments(attachments: list[AttachmentTrack]) -> List[str]:
     commands = []
     for attachment in attachments:
         if attachment.attachment_type == "cover":
             mime_type, ext_type = image_type(attachment.file_path)
-            clean_path = clean_file_string(attachment.file_path)
-            commands.append(
-                f' -attach "{clean_path}" -metadata:s:{attachment.outdex} mimetype="{mime_type}" '
-                f'-metadata:s:{attachment.outdex}  filename="{attachment.filename}.{ext_type}" '
+            commands.extend(
+                [
+                    "-attach",
+                    str(attachment.file_path),
+                    f"-metadata:s:{attachment.outdex}",
+                    f"mimetype={mime_type}",
+                    f"-metadata:s:{attachment.outdex}",
+                    f"filename={attachment.filename}.{ext_type}",
+                ]
             )
-    return " ".join(commands)
+    return commands
