@@ -74,7 +74,7 @@ class NVENCC(RigayaPanel):
         self.updating_settings = False
 
         grid.addLayout(self.init_modes(), 0, 2, 4, 4)
-        grid.addLayout(self._add_custom(title="Custom NVEncC options", disable_both_passes=True), 10, 0, 1, 6)
+        custom_layout = self._add_custom(title="Custom NVEncC options", disable_both_passes=True)
 
         grid.addLayout(self.init_preset(), 0, 0, 1, 2)
         # grid.addLayout(self.init_profile(), 1, 0, 1, 2)
@@ -143,10 +143,9 @@ class NVENCC(RigayaPanel):
                 app.fastflix.config.theme,
             )
         )
-
-        guide_label.setAlignment(QtCore.Qt.AlignBottom)
         guide_label.setOpenExternalLinks(True)
-        grid.addWidget(guide_label, 11, 0, 1, 4)
+        custom_layout.addWidget(guide_label)
+        grid.addLayout(custom_layout, 10, 0, 1, 6)
 
         self.setLayout(grid)
         self.hide()
