@@ -82,7 +82,7 @@ class QSVEnc(QSVEncPanel):
         self.updating_settings = False
 
         grid.addLayout(self.init_modes(), 0, 2, 4, 4)
-        grid.addLayout(self._add_custom(title="Custom QSVEncC options", disable_both_passes=True), 10, 0, 1, 6)
+        custom_layout = self._add_custom(title="Custom QSVEncC options", disable_both_passes=True)
 
         grid.addLayout(self.init_preset(), 0, 0, 1, 2)
         grid.addLayout(self.init_qp_mode(), 2, 0, 1, 2)
@@ -140,10 +140,9 @@ class QSVEnc(QSVEncPanel):
                 app.fastflix.config.theme,
             )
         )
-
-        guide_label.setAlignment(QtCore.Qt.AlignBottom)
         guide_label.setOpenExternalLinks(True)
-        grid.addWidget(guide_label, 11, 0, 1, 4)
+        custom_layout.addWidget(guide_label)
+        grid.addLayout(custom_layout, 10, 0, 1, 6)
 
         self.setLayout(grid)
         self.hide()
