@@ -41,4 +41,4 @@ class Logs(QtWidgets.QWidget):
 
     def closeEvent(self, event):
         self.hide()
-        # event.accept()
+        event.ignore()
