@@ -18,7 +18,7 @@ from fastflix.models.fastflix_app import FastFlixApp
 from fastflix.models.video import Video
 from fastflix.ff_queue import get_queue, save_queue, save_queue_async
 from fastflix.resources import get_icon, get_bool_env
-from fastflix.shared import no_border, open_folder, yes_no_message, message, error_message
+from fastflix.shared import no_border, open_folder, yes_no_message, message, error_message, shrink_text_to_fit
 from fastflix.ui_scale import scaler
 from fastflix.widgets.panels.abstract_list import FlixList
 from fastflix.exceptions import FastFlixInternalException
@@ -293,6 +293,17 @@ class EncodingQueue(FlixList):
         priority_label = QtWidgets.QLabel(t("Priority"))
         priority_label.setFixedWidth(55)
 
+        for w in (
+            self.save_queue_button,
+            self.load_queue_button,
+            self.clear_queue,
+            self.pause_queue,
+            self.pause_encode,
+            self.ignore_errors,
+            priority_label,
+        ):
+            shrink_text_to_fit(w)
+
         top_layout.addWidget(self.load_queue_button, QtCore.Qt.AlignRight)
         top_layout.addWidget(self.save_queue_button, QtCore.Qt.AlignRight)
         top_layout.addStretch(1)
@@ -540,6 +551,28 @@ class EncodingQueue(FlixList):
         if not self.main.build_commands():
             return False
 
+        # Re-resolve output filename with full encoder variables if user hasn't manually edited it
+        current_video = self.app.fastflix.current_video
+        if current_video.video_settings.template_generated_name and current_video.video_settings.output_path:
+            current_stem = current_video.video_settings.output_path.stem
+            if current_stem == current_video.video_settings.template_generated_name:
+                from fastflix.naming import resolve_pre_encode_variables, truncate_filename
+
+                gen_string = self.app.fastflix.config.output_name_format or "{source}-fastflix-{rand_4}"
+                new_name = resolve_pre_encode_variables(
+                    gen_string,
+                    current_video.source,
+                    video=current_video,
+                    encoder_settings=current_video.video_settings.video_encoder_settings,
+                    video_settings=current_video.video_settings,
+                )
+                directory = str(current_video.video_settings.output_path.parent)
+                extension = current_video.video_settings.output_path.suffix
+                new_name, _ = truncate_filename(new_name, directory, extension)
+                new_path = current_video.video_settings.output_path.with_stem(new_name)
+                current_video.video_settings.output_path = new_path
+                current_video.video_settings.template_generated_name = new_name
+
         for video in self.app.fastflix.conversion_list:
             if video.status.complete:
                 continue
